@@ -3,6 +3,7 @@ from easy import eagle
 
 def play(app, button):
     audio.play(app['file_name'])
+    audio.set_volume(10)
 
 def pause(app, button):
     audio.pause()
@@ -21,9 +22,8 @@ def rec_callback():
     pass
 
 app = eagle.App(title='Easy Recorder', 
-
-                top=eagle.Entry(id='file_name', value='./rec.mp3'),
-
+                #Now in Chinook, one must put the complete path. Do not uset ./
+                top=eagle.Entry(id='file_name', value='/home/user/record.mp3'),
                 bottom=(eagle.Button(id='record', label='Record',
                                      callback=record),
                         eagle.Button(id='rec_asyn',  label='Record Async',
