@@ -3,10 +3,16 @@ from easy import eagle
 
 def play(app, button):
     camera.play(filename=app['file_name'])
+    camera.set_volume(10)
 
 def pause(app, button):
     camera.pause()
 
+    if app['pause'].label == 'Pause':
+        app['pause'].label = 'Resume'
+    else:
+        app['pause'].label = 'Pause'
+
 def stop(app, button):
     camera.stop_playing()
 
