@@ -26,12 +26,10 @@ def exit_callback(app):
 app = eagle.App(title='Easy Radio', quit_callback=exit_callback,
                 top=(eagle.Button(id='previous_station', label='<<', callback=previous_station),
                      eagle.Button(id='next', label='  -  ', callback=tune_minus),
-                     eagle.Slider(id='frequency', label='Frequency(MHz)',
-                                  min= 87.5, max=106.9, value=93.1, digits=1,
-                                  callback=tune),
-                     eagle.Button (id='previous', label='  +  ',  callback=tune_plus),
+                     eagle.Slider(id='frequency', label='Frequency(MHz)', min=87.5,
+                                  max=106.9, value=93.1, digits=1, callback=tune),
+                     eagle.Button (id='previous', label='  +  ', callback=tune_plus),
                      eagle.Button(id='next_station', label='>>', callback=next_station)),
-
                 bottom=eagle.Slider(id='volume', label='Volume', min=0.0, max=10.0,
                                     value=5, digits=1, callback=set_volume))
 
