@@ -25,8 +25,19 @@
 module uses LightBlue a cross-platform Python Bluetooth API which provides
 simple access to Bluetooth operations (http://lightblue.sourceforge.net/).
 """
-from lightblue import *
+import lightblue as bluetooth
 
 __all__ = ["finddevices", "findservices", "finddevicename", "gethostaddr", 
            "gethostclass", "socket", "advertise", "stopadvertise",
-           "selectdevice", "selectservice"]
\ No newline at end of file
+           "selectdevice", "selectservice"]
+
+finddevicename = bluetooth.finddevicename
+finddevices = bluetooth.finddevices
+findservices = bluetooth.findservices
+gethostaddr = bluetooth.gethostaddr
+gethostclass = bluetooth.gethostclass
+obex = bluetooth.obex
+selectdevice = bluetooth.selectdevice
+selectservice = bluetooth.selectservice
+socket = bluetooth.socket
+stopadvertise = bluetooth.stopadvertise
\ No newline at end of file
