@@ -30,11 +30,13 @@ import thread
 
 import easy_exceptions
 
-__all__ = ["is_playing", "is_paused", "is_recording", "is_started",
-           "is_stopped", "play", "start", "pause", "stop_displaying",
-           "stop_recording", "stop_playing", "record", "record_async", "click",
-           "click_async", "get_length", "get_current_position", "seek",
-           "configure", "set_window_id"]
+__all__ = ["RESOLUTION_176x144", "RESOLUTION_320x240", "RESOLUTION_352x288",
+           "RESOLUTION_640x480", "is_playing", "is_paused", "is_recording",
+           "is_started", "is_stopped", "play", "start", "pause", 
+           "stop_displaying", "stop_recording", "stop_playing", "record", 
+           "record_async", "click", "click_async", "get_length", 
+           "get_current_position", "seek", "configure", "set_window_id",
+           "get_volume", "set_volume"]
 
 class FileNotExistError(easy_exceptions.EasyError): pass
 class DeviceNotStartedError(easy_exceptions.EasyError): pass
@@ -56,6 +58,11 @@ class Camera(object):
     done in a synchronous or asynchronous way.
     """
 
+    RESOLUTION_176x144 = (176,144)
+    RESOLUTION_320x240 = (320,240)
+    RESOLUTION_352x288 = (352,288)
+    RESOLUTION_640x480 = (640,480)
+
     def __init__(self):
         """Constructor for Camera class.
         """
@@ -63,16 +70,14 @@ class Camera(object):
         self._PAUSED = False
         self._RECORDING = False
         self._STARTING = False
-
+        
         self._current_pipeline = None
         self._window_id = None
-
-        self._playback_pipeline = gst.parse_launch("playbinmaemo")
-        self._make_source_pipeline()
-
-        self._make_display_bin()
-        self._make_recorder_bin()
-
+        
+        self._vsink = gst.element_factory_make("xvimagesink")
+        self._playback_pipeline = gst.parse_launch("playbin name=playback_sink")
+        self._playback_pipeline.set_property("video-sink", self._vsink)
+        
         self.time_format = gst.Format(gst.FORMAT_TIME)
 
     def _set_playback_pipeline(self):
@@ -87,28 +92,25 @@ class Camera(object):
         """
         self._current_pipeline = self._source_pipeline
 
-    def _make_source_pipeline(self):
+    def _make_source_pipeline(self, resolution):
         """Build a GStreamer pipeline.
         """
         self._source_pipeline = gst.Pipeline("source_pipeline")
 
-        source = gst.element_factory_make("gconfv4l2src", "source")
+        source = gst.element_factory_make("v4l2src", "source")
         filter = gst.element_factory_make("capsfilter", "source_filter")
-        fakesink = gst.element_factory_make("fakesink", "fake_sink")
         self._tee = gst.element_factory_make("tee", "tee")
 
-        caps = gst.Caps("video/x-raw-yuv,width=176,height=144")
+        caps = gst.Caps("video/x-raw-yuv,width=%i,height=%i,framerate=8/1" % resolution)
 
         self._source_pipeline.add(source)
         self._source_pipeline.add(filter)
         self._source_pipeline.add(self._tee)
-        self._source_pipeline.add(fakesink)
 
         filter.set_property("caps", caps)
 
         source.link(filter)
         filter.link(self._tee)
-        self._tee.link(fakesink)
 
     def _make_display_bin(self):
         """Build a GStreamer bin to display camera's image in the screen.
@@ -229,7 +231,7 @@ class Camera(object):
             self._set_playback_file(filename)
 
             if self._window_id:
-                self._playback_pipeline.set_property("xid", self._window_id)
+                self._vsink.set_xwindow_id(self._window_id)
 
             self._current_pipeline.set_state(gst.STATE_PLAYING)
             self._PLAYING = True
@@ -240,15 +242,17 @@ class Camera(object):
         else:
             raise FileNotExistError("File does not exist")
 
-    def start(self, start_time=None):
+    def start(self, start_time=None, resolution=RESOLUTION_352x288):
         """Start showing camera display.
 
         @type  start_time: number
-        @param start_time: total time, in seconds, of the recorded file
+        @param start_time: total time, in seconds, that camera will be started
+        @type  resolution: tuple
+        @param resolution: resolution that camera will be started (176x144, 320x240, 352x288 or 640x480)
         """
-        self._set_source_pipeline()
-
-        if not self._STARTING:
+        if not self.is_started():
+            self._make_source_pipeline(resolution)
+            self._make_display_bin()
             self._tee.link(self._display_bin)
 
         if self._window_id:
@@ -259,7 +263,7 @@ class Camera(object):
         self._STARTING = True
         if start_time:
             time.sleep(start_time)
-            self.stop()
+            self.stop_displaying()
 
     def pause(self):
         """Pause the current playing video file.
@@ -276,13 +280,14 @@ class Camera(object):
     def stop_displaying(self):
         """Stop the current camera display.
         """
-        self._source_pipeline.set_state(gst.STATE_NULL)
-        self._tee.unlink(self._display_bin)
-
-        self._PLAYING = False
-        self._PAUSED = False
-        self._RECORDING = False
-        self._STARTING = False
+        if self.is_started():
+            self._tee.unlink(self._display_bin)
+            self._source_pipeline.set_state(gst.STATE_NULL)
+            
+            self._PLAYING = False
+            self._PAUSED = False
+            self._RECORDING = False
+            self._STARTING = False
 
     def stop_recording(self, callback=None):
         """Stop recording video.
@@ -292,6 +297,7 @@ class Camera(object):
        """
         if self.is_recording():
             self._tee.unlink(self._recorder_bin)
+            self._recorder_bin.set_state(gst.STATE_NULL)
             self._source_pipeline.remove(self._recorder_bin)
 
             self._RECORDING = False
@@ -310,7 +316,7 @@ class Camera(object):
             self._STARTING = False
 
     def record(self, filename="file.avi", record_time=None, delay=0,
-               callback=None):
+               resolution=RESOLUTION_352x288, callback=None):
         """Record image captured by the camera in a syncronous way. The
         program's main thread is blocked in this process.
 
@@ -321,27 +327,27 @@ class Camera(object):
         @type        delay: number
         @param       delay: delay time, in seconds, that will be waited until
                             start recording
+        @type   resolution: tuple
+        @param  resolution: resolution that camera will record (176x144, 320x240, 352x288 or 640x480)
         @type     callback: function
         @param    callback: function that will be called as a callback after
                             record
         """
+        if not self.is_started():
+            self.start(resolution=resolution)
+
         self._make_recorder_bin()
         self._source_pipeline.add(self._recorder_bin)
 
         self._set_recorder_file(filename)
         self._tee.link(self._recorder_bin)
         # Needed time to record correctly
-        time.sleep(0.4)
+        time.sleep(0.4 + delay)
 
-        time.sleep(delay)
-        if not self.is_started():
-            self._source_pipeline.remove(self._display_bin)
         self._source_pipeline.set_state(gst.STATE_PLAYING)
 
         self._RECORDING = True
 
-        if not self.is_started():
-            self._source_pipeline.add(self._display_bin)
         if record_time:
             time.sleep(record_time)
             self.stop_recording(callback)
@@ -372,27 +378,23 @@ class Camera(object):
         @param filename: name of the captured picture
         @type     delay: number
         @param    delay: delay time, in seconds, that will be waited until
-                            start recording
+                         capture a picture
         """
+        if not self.is_started():
+            self.start()
+
         self._make_snapshot_bin()
         self._set_photo_file(filename)
-
-        time.sleep(delay)
-
-        if not self.is_started():
-            self._source_pipeline.remove(self._display_bin)
-
         self._source_pipeline.set_state(gst.STATE_PLAYING)
-
-        time.sleep(0.4)
+        # Needed time to record correctly
+        time.sleep(0.4 + delay)
 
         self._tee.link(self._snapshot_bin)
         time.sleep(1)
         self._tee.unlink(self._snapshot_bin)
 
+        self._snapshot_bin.set_state(gst.STATE_NULL)
         self._source_pipeline.remove(self._snapshot_bin)
-        if not self.is_started():
-            self._source_pipeline.add(self._display_bin)
 
     def click_async(self, filename="pic.jpg", delay=0):
         """Capture an image via camera in an asynchronous way. The program's
@@ -475,6 +477,38 @@ class Camera(object):
         """
         self._window_id = window_id
 
+    def get_volume(self):
+        """Return the volume level of the played audio file.
+
+        @rtype:  long integer
+        @return: volume level of the played audio file
+        """
+        element = self._get_current_sink_element()
+        return element.get_property("volume")
+
+    def set_volume(self, volume=None):
+        """Set the volume level of the played audio file. The values range is
+        from 0.0 to 10.0.
+
+        @type  volume: double
+        @param volume: number that set volume level, ranged from 0.0 to 10.0
+        """
+        if volume == None:
+            raise VolumeNotSpecifiedError("Volume not specified")
+
+        element = self._get_current_sink_element()
+        element.set_property("volume", volume)    
+
+    def _get_current_sink_element(self):
+        """Gets the sink element from pipeline.
+        """
+        # For pipelines containing only one element. (playback_pipeline)
+        if self._current_pipeline.get_name() == "playback_sink":
+            element = self._current_pipeline
+        else:
+            element = self._current_pipeline.get_by_name("sink")
+        return element
+    
     def _set_color_property(self, property, value):
         #TODO - maemo gstreamer doesn't allows this function
         """Set image color property.
@@ -535,6 +569,10 @@ class Camera(object):
 
 _camera = Camera()
 
+RESOLUTION_176x144 = _camera.RESOLUTION_176x144
+RESOLUTION_320x240 = _camera.RESOLUTION_320x240
+RESOLUTION_352x288 = _camera.RESOLUTION_352x288
+RESOLUTION_640x480 = _camera.RESOLUTION_640x480
 is_playing = _camera.is_playing
 is_paused = _camera.is_paused
 is_recording = _camera.is_recording
@@ -554,4 +592,6 @@ get_length = _camera.get_length
 get_current_position = _camera.get_current_position
 seek = _camera.seek
 configure = _camera.configure
-set_window_id = _camera.set_window_id
\ No newline at end of file
+set_window_id = _camera.set_window_id
+get_volume = _camera.get_volume 
+set_volume = _camera.set_volume
\ No newline at end of file
